@@ -5,7 +5,7 @@ int get_key_size(int algorithm); /* returns key in bytes */
 
 char* get_algorithms_name(int algorithm);
 
-int init_mcrypt ( const int algorithm, void * key, int lenofkey);
+int init_mcrypt ( const int algorithm, int thread, void * key, int lenofkey);
 int mcrypt(int thread, void *plaintext);
 int mdecrypt(int thread, void *plaintext);
 int end_mcrypt(int td);
